@@ -154,6 +154,8 @@ WIN32           gcc-mingw32 or lcc-win32 / Microsoft Windows 95/98/NT
 #define TMPDIR P_tmpdir
 #endif
 #define OUTDIR "."
+#define BASEDIR "/weather/wxdata/"
+#define TRACKDIR BASEDIR "rxtrack"
 #define NULLDEVICE "/dev/null"
 #define COPYCMD "/bin/cp -f %s %s"
 #define PATHSEPARATOR "/"
@@ -183,11 +185,15 @@ WIN32           gcc-mingw32 or lcc-win32 / Microsoft Windows 95/98/NT
 unsigned long pktcount =0 ;
 unsigned long badpktcount = 0;
 unsigned char *outdir = OUTDIR;
+unsigned char *basedir = BASEDIR;
+unsigned char *trackdir = TRACKDIR;
 unsigned char *tmpdir = TMPDIR;
 unsigned char *unzippath = UNZIPPATH;
+unsigned char *pathseparator = PATHSEPARATOR;
 int outmode = OUTMODE;
 int beepmode = BEEPMODE;
 int debug = DEBUG;
+int recompat=0;
 
 struct QBT {	/* http://iwin.nws.noaa.gov/emwin/winpro.htm */
   unsigned char preamble[6];
@@ -437,14 +443,17 @@ int saveblock(const struct PKTATTR *pktp, unsigned char *savedfilepath) {
                 trackpath[MAXPATHLEN], datapath[MAXPATHLEN];
 
   /* Construct the full file paths. */
+  sprintf(datapath, "%s" PATHSEPARATOR "%s", tmpdir, pktp->filename);
 #if defined(WIN32) || defined(__EMX__)
-  sprintf(datapath, "%s" PATHSEPARATOR "%s", TMPDIR, pktp->filename);
   sprintf(trackpath, "%s" PATHSEPARATOR "%s", TRACKDIR, pktp->filename);
 #else
+  if (recompat) {
+    sprintf(trackpath, "%s" PATHSEPARATOR "%s", trackdir, pktp->filename);
+  } else {
   /* In UNIX use the same tmpdir to store the tracking file but
      add a '.track' suffix to the filename. */
-  sprintf(datapath, "%s" PATHSEPARATOR "%s", tmpdir, pktp->filename);
   sprintf(trackpath, "%s.track", datapath);
+  }
 #endif
 
   newfile = FALSE;
@@ -554,6 +563,7 @@ void showusage(void) {
     "-o output-directory  Directory to place completed files\n"
     "                     (default = %s).\n"
 #if !defined(WIN32) && !defined(__EMX__)
+    "-w                   Use RealEmwin compatable directory structure\n"
     "-t temp-directory    Directory to place temporary files\n"
     "                     (default = %s).\n"
 #endif
@@ -597,6 +607,9 @@ int main(const int argc, const char *argv[]) {
         i++;
         break;
 #ifndef WIN32
+      case 'w':  /* compat enable. */
+        recompat = 1;
+        break;
       case 't':  /* Temp directory for incomplete files and block
                  tracking files. */
         if (i+1 < argc) tmpdir = (unsigned char *)argv[i+1];
@@ -658,6 +671,12 @@ int main(const int argc, const char *argv[]) {
     }
   }
 
+  if (recompat) { /* This may be of interest when using samba */
+     basedir = strcat(outdir,"wxdata");
+     trackdir = strcat(basedir,"rxtrack");
+     tmpdir = strcat(basedir,"rxtmp/tmp");
+     outdir = strcat(basedir,"newfiles");
+  }
   /* Preliminary error checks before we redirect diagnostic output to 
      /dev/null. */
   if (outmode > 1) {
